file_names = [
    "index",  # If your Theme provides its own templates, index.php must be present
    "comments",  # The comments template
    "front-page",  # The front page template
    "header",  # The head of the html document
    "home",  # The home page template, which is the front page by default. If you use a static front page this is the template for the page with the latest posts
    "single",  # Used when a single post is queried, index.php is used if the query template is not present.  Use also, "single-{post-type}.php" for displaying single posts of a custom post type
    "page",  # Used when a single page is queried
    "category",  # Used when a category is queried
    "tag",  # Used whe a tag is queried
    "taxonomy",  # Used when a term in a custom taxonomy is queried
    "author",  # Used when an author is queried
    "date",  # Used when a date or time is queried. Year, month, day, hour, minute, second
    "archive",  # Used when a category, author, or date is queried. Note that this template will be overridden by category.php, author.php, and date.php for their respective query types
    "search",  # Used when a search is performed
    "attachment",  # Used when viewing a single attachment
    "image",  # Used when viewing a single image attachment. If not present, attachment.php will be used
    "404",  # Used when WordPress cannot find a post or page that matches the query
    "functions",  # Default functions
    "style",  # Meta Data Sheet
    "main",  # Main Style Sheet.  If Sass is used this is the file to overwrite
    "footer",  # The foot of the html document
]


import os, click
from .snippets.css import (
    meta_data,
    default_style,
)
from .snippets.html import (
    default_footer_content,
    default_header_content,
    default_home_content,
    default_page_content,
)
from .snippets.php import (
    default_functions,
    default_theme_options,
    functions_no_bs,
    golden_content,
)
from .snippets.sass import (
    default_sass,
)
from .vars import file_names


@click.command()
@click.option(
    "--theme_name",
    default="custom_theme",
    help="Change the theme name.  Default: 'custom_theme'",
)
@click.option(
    "--classic",
    default=True,
    help='Determines whether template files should be classic "php" (True) or block style "html" (False).  Default: True',
)
@click.option(
    "--bootstrap",
    default=True,
    help="Determines whether or not to use bootstrap.  Default: True",
)
@click.option(
    "--sass", default=True, help="Determines whether or not to use Sass.  Default: True"
)
def cli(theme_name, classic, bootstrap, sass):
    """Create the default files for the custom theme"""
    base_url = os.getcwd()
    base_url += f"\\{theme_name}"

    os.mkdir(base_url)
    os.mkdir(f"{base_url}\\css\\")
    os.mkdir(f"{base_url}\\assets\\")
    os.mkdir(f"{base_url}\\includes\\")

    if sass:
        with open(f"{base_url}\\main.scss", "w") as f:
            f.write(default_sass())

    for filename in file_names:
        base_filename = f"{base_url}\\{filename}"
        if filename == "style":
            file_name = f"{base_filename}.css"
            data = meta_data
        elif filename == "functions":
            file_name = f"{base_filename}.php"
            if bootstrap:
                data = default_functions()
            else:
                data = functions_no_bs()

            data += default_theme_options()
        elif filename == "main":
            file_name = f"{base_url}\\css\\{filename}.css"
            data = default_style()
        else:
            file_name = f"{base_filename}.php" if classic else f"{base_filename}.html"
            if filename == "header":
                data = default_header_content()
            elif filename == "page":
                data = default_page_content()
            elif filename == "home":
                data = default_home_content()
            elif filename == "footer":
                data = default_footer_content()
            else:
                data = golden_content() if classic else f"<h1>{filename}</h1>"

        with open(file_name, "w") as f:
            f.write(str(data))


if __name__ == "__main__":
    cli()



def default_header_content() -> str:
    return """
<!DOCTYPE html>
<html lang="en">

<head>
    <meta charset="UTF-8">
    <meta http-equiv="X-UA-Compatible" content="IE=edge">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">

    <?php wp_head(); ?>

    <title>Default Title | <?php the_title(); ?></title>
</head>
<body>
    <header>
        <nav class="navbar navbar-light navbar-expand-lg">
            <div class="container">
                <span class="navbar-brand mb-0 h1">
                    <img class="rounded" src="https://picsum.photos/80?grayscale" />
                </span>
                <button class="navbar-toggler" type="button" data-bs-toggle="collapse" data-bs-target="#navbarNav"
                    aria-controls="navbarNav" aria-expanded="false" aria-label="Toggle navigation">
                    <span class="navbar-toggler-icon"></span>
                </button>
                <div class="collapse navbar-collapse" id="navbarNav">
                    <!-- Replace with wordpress menu if you like -->
                    <!--<?php  wp_nav_menu(
                        array(
                            'menu' => 'primary',
                            'menu_class' => 'navbar-nav'
                        )
                    ); ?>-->
                    <ul class="navbar-nav text-center">
                        <li class="nav-item">
                            <a class="nav-link active" aria-current="page" href="#">Home</a>
                        </li>
                        <li class="nav-item">
                            <a class="nav-link" href="#">Features</a>
                        </li>
                        <li class="nav-item">
                            <a class="nav-link" href="#">Pricing</a>
                        </li>
                        <li class="nav-item">
                            <a class="nav-link disabled">Disabled</a>
                        </li>
                    </ul>
                </div>
            </div>
        </nav>
    </header>
"""

def default_page_content() -> str:
    return """
<?php get_header(); ?>

<div class="container">
    <div class="dummy_text">
        <?php the_content(); ?>
    </div>
</div>

<?php get_footer(); ?>
"""

def default_home_content() -> str:
    return """
<?php get_header(); ?>

    <section id="hero" style="background-image: url('https://picsum.photos/1920/1080'); background-size: cover; background-attachment: fixed;">
        <div class="overlay"></div>
        <div class="container">
            <div class="call_to_action text-center">
                <h3 class="action_title">Are You Looking to <b><i>Build</i></b> and <b><i>Develop</i></b> a Custom Wordpress Theme?<br><b><i>I'm Here to
                            Help!</i></b></h3>
                <hr>
                <p class="action_desc">Contact Me Today For a <b><i>FREE</i></b> Home Staging Guide</p>
                <div class="row">
                    <div class="col">
                        <input type="text" class="form-control" placeholder="Email Address" />
                    </div>
                    <div class="col">
                        <a href="#" class="btn btn-info text-white"><b>CLAIM YOUR GUIDE</b></a>
                    </div>
                </div>
            </div>
        </div>
    </section>
    <section id="#"></section>
    <section id="#"></section>
    <section id="#"></section>
    <section id="contact_us">
        <div class="container">
            <footer>
                <div class="container">
                    <small>&copy; Created by WSK | Powered by Python | <a href="#"><i class="fa-brands fa-facebook"></i></a>
                        <a href="#"><i class="fa-brands fa-youtube"></i></a> <a href="#"><i
                                class="fa-brands fa-instagram"></i></a> <a href="#"><i
                                class="fa-brands fa-twitter"></i></a></small>
                </div>
            </footer>
        </div>
    </section>

<?php get_footer(); ?>
"""

def default_footer_content() -> str:
    return """
        <?php wp_footer(); ?>
    </body>
</html>
"""


def golden_content() -> str:
    """The Default Content for Empty PHP Files"""
    return """
<?php
    // Silence is Golden 
"""

def default_functions() -> str:
    return """
<?php

function load_css() {
    // Bootstrap
    wp_register_style('BootstrapCSS', 'https://cdn.jsdelivr.net/npm/bootstrap@5.2.3/dist/css/bootstrap.min.css');
    wp_enqueue_style('BootstrapCSS');

    // Custom
    wp_register_style('mainCSS', get_template_directory_uri() . '/css/main.css', array(), '1.0');
    wp_enqueue_style('mainCSS');
}
add_action('wp_enqueue_scripts', 'load_css');

function load_js() {
    // FontAwesome 6
    wp_register_script('FontAwesome', 'https://kit.fontawesome.com/dc8a96ec90.js', array(), '6.2.1', false);
    wp_enqueue_script('FontAwesome');
    
    // Bootstrap
    wp_register_script('BootstrapJS', 'https://cdn.jsdelivr.net/npm/bootstrap@5.2.3/dist/js/bootstrap.bundle.min.js', array(), '5.2.3', true);
    wp_enqueue_script('BootstrapJS');
}
add_action('wp_enqueue_scripts', 'load_js');
"""

def functions_no_bs() -> str:
    return """
<?php

function load_css() {
    wp_register_style('mainCSS', get_template_directory_uri() . '/css/main.css', array(), '1.0');
    wp_enqueue_style('mainCSS');
}
add_action('wp_enqueue_scripts', 'load_css');

function load_js() {
    // FontAwesome 6
    wp_register_script('FontAwesome', 'https://kit.fontawesome.com/dc8a96ec90.js', array(), '6.2.1', false);
    wp_enqueue_script('FontAwesome');
}
add_action('wp_enqueue_scripts', 'load_js');   
"""

def default_theme_options() -> str:
    return """
// Theme Options
add_theme_support('menus');

// Add Thumbnail Support
function thumbnail_support() {
    add_theme_support( 'post-thumbnails' );
}
add_action('after_setup_theme', 'thumbnail_support');
"""


def meta_data() -> str:
    """The Meta Data for the Custom Wordpress Theme"""
    return """
/*
Theme Name: Custom Theme
Author: Author Name
Description: A custom WP Theme made with WSK
Version: 1.0
*/
"""

def default_style() -> str:
    """The Default CSS Content"""
    return """
#hero {
    position: relative;
    height: calc(100vh - 6.7rem);
}

.overlay {
    position: relative;
    height: 100%;
    width: 100%;
    background-color: #fff;
    opacity: 0.8;
    z-index: 1;
}

.call_to_action {
    position: absolute;
    top: 25vh;
    max-width: 90vw;
    z-index: 5;
}
"""


from .css import meta_data, default_style
from .html import (
    default_header_content,
    default_page_content,
    default_home_content,
    default_footer_content,
)
from .php import (
    golden_content,
    default_functions,
    functions_no_bs,
    default_theme_options,
)
from .sass import default_sass



def default_sass() -> str:
    return """
.overlay {
    position: relative;
    height: 100%;
    width: 100%;
    background-color: #fff;
    opacity: 0.8;
    z-index: 1;
}

#hero {
    position: relative;
    height: calc(100vh - 6.7rem);

    .call_to_action {
        position: absolute;
        top: 25vh;
        max-width: 90vw;
        z-index: 5;
    }
}
"""